==========
Developing
==========

:Author:
    `gocept <http://gocept.com/>`_ <mail@gocept.com>

:Online documentation:
    https://pythonhosted.org/zodb.py3migrate/

:PyPI page:
    https://pypi.python.org/pypi/zodb.py3migrate

:Issues:
    https://github.com/gocept/zodb.py3migrate/issues

:Source code:
    https://github.com/gocept/zodb.py3migrate

:Current change log:
    https://raw.githubusercontent.com/gocept/zodb.py3migrate/master/CHANGES.rst
